@@ -1,5 +1,5 @@
 package Backup::EZ;
-$Backup::EZ::VERSION = '0.44';
+$Backup::EZ::VERSION = '0.45';
 use strict;
 use warnings;
 use warnings FATAL => 'all';
@@ -25,6 +25,7 @@ use constant COPIES                  => 30;
 use constant DEST_HOSTNAME           => 'localhost';
 use constant DEST_APPEND_MACH_ID     => 0;
 use constant USE_SUDO                => 0;
+use constant IGNORE_VANISHED         => 0;
 use constant DEFAULT_ARCHIVE_OPTS    => '-az';
 use constant ARCHIVE_NO_RECURSE_OPTS => '-dlptgoDz';
 
@@ -34,7 +35,7 @@ Backup::EZ - Simple backups based on rsync
 
 =head1 VERSION
 
-version 0.44
+version 0.45
 
 =cut
 
@@ -161,6 +162,10 @@ sub _read_conf {
         if ( !defined $conf{use_sudo} ) {
             $conf{use_sudo} = USE_SUDO;
         }
+
+        if ( !defined $conf{ignore_vanished} ) {
+            $conf{ignore_vanished} = IGNORE_VANISHED;
+        }
     }
 
     if ( ref( $conf{dir} ) ne 'ARRAY' ) {
@@ -209,8 +214,12 @@ sub _ssh {
         $sshcmd = "$cmd";
     }
     else {
+        if ($cmd !~ /^ *sudo /) {
+            $cmd = sprintf( "%s $cmd", $self->{conf}->{use_sudo} ? 'sudo' : '' );
+        }
+
         my $ssh_opts = [];
-        if ( $self->{conf}->{ssh_opts} ){
+        if ( $self->{conf}->{ssh_opts} ) {
             push @$ssh_opts, $self->{conf}->{ssh_opts};
         }
         $sshcmd = sprintf( 'ssh %s %s %s', join( ' ', @{$ssh_opts}), $login, $cmd );
@@ -408,7 +417,16 @@ sub _rsync2 {
     system($cmd);
 
     # uncoverable branch true
-    confess if $?;
+    # uncoverable branch true
+    if ($?) {
+        my $exit = $? >> 8;
+        if ($exit == 24 && $self->{conf}->{ignore_vanished}) {
+            $self->_debug("ignoring vanished files");
+        }
+        else {
+            confess;
+        }
+    }
 }
 
 # Unused?
